@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2018 Sean Davis <smd.seandavis@gmail.com>
+#   Copyright (C) 2012-2019 Sean Davis <smd.seandavis@gmail.com>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -14,12 +14,13 @@
 #   PURPOSE.  See the GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License along
-#   with this program.  If not, see <http://www.gnu.org/licenses/>.
+#   with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 import logging
 
 import io
 import os
+import re
 import signal
 import subprocess
 import time
@@ -50,11 +51,21 @@ else:
     locate_support = False
 FNULL.close()
 
+def get_keyword_list(keywords):
+    keywords = keywords.replace(",", " ").strip().lower()
+    kwords = []
+    matches = re.findall(r'\"(.+?)\"', keywords)
+    for match in matches:
+        newmatch = match.replace(" ", "\0")
+        newmatch = newmatch.replace("\"", "")
+        keywords = keywords.replace("\"%s\"" % match, newmatch)
+    for keyword in keywords.split(" "):
+        kwords.append(keyword.replace("\0", " "))
+    return kwords
 
 def string_regex(keywords, path):
     """Returns a string with the regular expression containing all combinations
     of the keywords."""
-    keywords = keywords.split()
     if len(keywords) == 0:
         return ''
     if len(keywords) == 1:
@@ -133,38 +144,35 @@ class CatfishSearchEngine:
         self.start_time = time.time()
         self.stop_time = 0
 
-        keywords = keywords.replace(',', ' ').strip().lower()
+        keywords = get_keyword_list(keywords)
+        self.keywords = " ".join(keywords)
 
         logger.debug("[%i] path: %s, keywords: %s, limit: %i, regex: %s",
                      self.engine_id, str(path), str(keywords), limit,
                      str(regex))
 
-        self.keywords = keywords
-
         wildcard_chunks = []
-        for key in self.keywords.split():
+        keys = []
+        for key in keywords:
             if '*' in key:
                 wildcard_chunks.append(key.split('*'))
-
-        keywords = keywords.replace('*', ' ')
+            else:
+                keys.append(key)
 
         # For simplicity, make sure the path contains a trailing '/'
         if not path.endswith('/'):
             path += '/'
 
-        # Transform the keywords into a clean list.
-        keys = []
-        for key in keywords.split():
-            keys.append(key.strip())
-
         # Path exclusions for efficiency
         exclude = []
-        cache_path = os.path.expanduser("~/.cache")
-        if cache_path not in path:
-            exclude.append(cache_path)
-        gvfs_path = os.path.expanduser("~/.gvfs")
-        if gvfs_path not in path:
-            exclude.append(gvfs_path)
+        maybe_exclude = [
+            os.path.expanduser("~/.cache"),
+            os.path.expanduser("~/.gvfs"),
+            "/dev"
+        ]
+        for maybe_path in maybe_exclude:
+            if not path.startswith(maybe_path):
+                exclude.append(maybe_path)
 
         file_count = 0
         for method in self.methods:
@@ -290,12 +298,14 @@ class CatfishSearchMethod_Walk(CatfishSearchMethod):
         This function is a generator and will yield files as they are found or
         True if still running."""
         exclude = []
-        cache_path = os.path.expanduser("~/.cache")
-        if cache_path not in path:
-            exclude.append(cache_path)
-        gvfs_path = os.path.expanduser("~/.gvfs")
-        if gvfs_path not in path:
-            exclude.append(gvfs_path)
+        maybe_exclude = [
+            os.path.expanduser("~/.cache"),
+            os.path.expanduser("~/.gvfs"),
+            "/dev"
+        ]
+        for maybe_path in maybe_exclude:
+            if not path.startswith(maybe_path):
+                exclude.append(maybe_path)
 
         self.running = True
         if isinstance(keywords, str):
@@ -376,7 +386,7 @@ class CatfishSearchMethod_Fulltext(CatfishSearchMethod):
                                     break
 
                                 if self.exact:
-                                    if keywords in line:
+                                    if " ".join(keywords) in line:
                                         yield os.path.join(root, filename)
                                         break
                                 else:
