@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2018 Sean Davis <smd.seandavis@gmail.com>
+#   Copyright (C) 2012-2019 Sean Davis <smd.seandavis@gmail.com>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -14,7 +14,7 @@
 #   PURPOSE.  See the GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License along
-#   with this program.  If not, see <http://www.gnu.org/licenses/>.
+#   with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 import optparse
 
@@ -39,7 +39,7 @@ def parse_options():
                                    usage=usage)
     parser.add_option(
         "-v", "--verbose", action="count", dest="verbose",
-        help=_("Show debug messages (-vv debugs catfish_lib also)"))
+        help=_("Show debug messages (-vv will also debug catfish_lib)"))
 
     parser.add_option('', '--large-icons', action='store_true',
                       dest='icons_large', help=_('Use large icons'))
@@ -48,7 +48,7 @@ def parse_options():
     parser.add_option('', '--iso-time', action='store_true',
                       dest='time_iso', help=_('Display time in ISO format'))
     # Translators: Do not translate PATH, it is a variable.
-    parser.add_option('', '--path', help=optparse.SUPPRESS_HELP)
+    parser.add_option('', '--path', help=_("Set the default search path"))
     parser.add_option('', '--exact', action='store_true',
                       help=_('Perform exact match'))
     parser.add_option('', '--hidden', action='store_true',
